jaclearn.imageaug
=================

.. automodule:: jaclearn.imageaug

   
   
   

   
   
   

   
   
   

   
   
   



.. rubric:: Submodules
.. autosummary::
   :toctree:
   :template: base.rst
   :recursive:

   cblk
   executor
   photography
   shape









